@@ -37,7 +37,8 @@ def get_google_ads(start_date, end_date, admin_account,
 
     _locale._getdefaultlocale = (lambda *args: ['en_US', 'UTF-8'])
     
-    googleads_client = GoogleAdsClient.load_from_storage('googleads.yaml')
+    #googleads_client = GoogleAdsClient.load_from_storage('googleads.yaml')
+    googleads_client = GoogleAdsClient.load_from_storage(yaml_file_path)
     
     ga_service = googleads_client.get_service("GoogleAdsService")
     
