@@ -307,7 +307,7 @@ def run_test(query = '',
 
                     if columns != []:  
 
-                        if check_col_names(response, position) == set(columns):
+                        if response.json()[0]['attachment']['body'][position]['component_type'] == 'table' and check_col_names(response, position) == set(columns):
 
                             print('Check for column names in table passed')
 
