@@ -9,31 +9,31 @@ if __name__ == "__main__":
         queries=[
             Query(
                 fields=[
-                    Field(aggregation="SUM", column="incidents", alias="sum_incidents",
+                    Field(aggregation="SUM", column="{{measure.A}}", alias="{{measAlias.A}}",
                           internalDataType="NUMERIC",
                           sourceDataType="INT64"),
-                    Field(column="customer_name", alias="Customer",
+                    Field(column="{{dimension.A}}", alias="{{dimAlias.A}}",
                           internalDataType="STRING",
                           sourceDataType="VARCHAR"),
-                    Field(aggregation="YEAR", column="acquired", alias="Acquired Date",
+                    Field(aggregation="YEAR", column="{{timeDimension.A}}", alias="{{timeDimAlias.A}}",
                           internalDataType="DATE",
                           sourceDataType="DATE")
                 ],
                 where=[
                     CompositeCondition(conditions=[
-                        Condition(field=Field(column="customer_name", alias="Customer",
+                        Condition(field=Field(column="{{dimension.A}}", alias="{{dimAlias.A}}",
                                               internalDataType="STRING",
                                               sourceDataType="VARCHAR"), operator=SQLOperator.IN,
-                                  value=["Franceaco Doe", "Claude Rudolf"]),
-                        Condition(field=Field(aggregation="YEAR", column="acquired", alias="Acquired Date",
+                                  value=["{{entity.A}}", "{{entity.A}}"]),
+                        Condition(field=Field(aggregation="YEAR", column="{{timeDimension.A}}", alias="{{timeDimAlias.A}}",
                                               internalDataType="DATE",
                                               sourceDataType="DATE"), operator=TimeOperator.RANGE,
-                                  value=["2018-01-01", "2019-12-31"])
+                                  value=["{{timePeriodStart.A}}", "{{timePeriodEnd.A}}"])
                     ], operator=BooleanOperator.AND)
 
                 ],
                 orderBy=[
-                    Sorting(field="Acquired Date", order=SQLSorting.DESC)
+                    Sorting(field="{{timeDimension.A}}", order=SQLSorting.DESC)
                 ],
                 limit=6
             )
