@@ -1,11 +1,12 @@
 from askdata.smartgraph import smart_title
 
 if __name__ == "__main__":
-    smartquery = {"queries": [{"datasets": [], "fields": [
-        {"aggregation": "MAX", "column": "totale_casi", "internalDataType": "NUMERIC"},
-        {"aggregation": "AVG", "column": "deceduti", "internalDataType": "NUMERIC"},
-        {"column": "denominazione_regione", "internalDataType": "STRING"},
-        {"column": "monthly", "internalDataType": "DATE"}], "id": "q0", "limit": "3",
+    smartquery = {"components": [{"type": "chart", "queryId": "q0", "chartType": "LINE"}],
+                  "queries": [{"datasets": [], "fields": [
+                      {"aggregation": "MAX", "column": "totale_casi", "internalDataType": "NUMERIC"},
+                      {"aggregation": "AVG", "column": "deceduti", "internalDataType": "NUMERIC"},
+                      {"column": "denominazione_regione", "internalDataType": "STRING"},
+                      {"column": "monthly", "internalDataType": "DATE"}], "id": "q0", "limit": "3",
                                "where": [{"field": {"column": "deceduti"}, "operator": "GOE", "value": ["30"]},
                                          {"field": {"column": "denominazione_regione"}, "operator": "IN",
                                           "negate": True, "value": ["Lazio"]},
@@ -15,5 +16,7 @@ if __name__ == "__main__":
                                           "steps": "2"}]}]}
     metadata = {"totale_casi": "Totale casi", "deceduti": "Deceduti", "denominazione_regione": "Regione",
                 "monthly": "Monthly"}
-    title = smart_title(smartquery=smartquery, metadata=metadata, lang="en-US")
+    title = smart_title(smartquery=smartquery, metadata=metadata, lang="en-US", update=False)
+    print(title)
+    title = smart_title(smartquery=smartquery, metadata=metadata, lang="en-US", update=True)
     print(title)
